@@ -9,7 +9,7 @@ for d3.js without taking away the power that d3.js gives you.
 Project location : https://github.com/areski/python-nvd3
 """
 
-from NVD3Chart import NVD3Chart, stab
+from .NVD3Chart import NVD3Chart, stab
 
 
 class scatterChart(NVD3Chart):
